'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

exports.__esModule = true;

var _index = require('./metrics/event/index');

var _index2 = _interopRequireDefault(_index);

var _index3 = require('./metrics/interval/index');

var _index4 = _interopRequireDefault(_index3);

var _MetricsSender = require('./MetricsSender');

var _MetricsSender2 = _interopRequireDefault(_MetricsSender);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var Monitor = function () {
  function Monitor() {
    var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
    (0, _classCallCheck3.default)(this, Monitor);

    this.interval = options.interval || 1000 * 30;
    this.sender = new _MetricsSender2.default(options);
    this.eventMetrics = this.initEventMetrics((0, _extends3.default)({}, options, { sender: this.sender }));
    this.intervalMetrics = this.initIntervalMetrics((0, _extends3.default)({}, options, { interval: this.interval }));
    this.setDefaultEvents();
  }

  Monitor.prototype.setDefaultEvents = function setDefaultEvents() {
    var _this = this;

    setInterval(function () {
      _this.sender.send(_this.getIntervalMetrics());
    }, this.interval);
  };

  Monitor.prototype.initEventMetrics = function initEventMetrics(options) {
    var metrics = {};
    (0, _keys2.default)(_index2.default).map(function (key) {
      metrics[key] = new _index2.default[key](options);
    });
    return metrics;
  };

  Monitor.prototype.initIntervalMetrics = function initIntervalMetrics(options) {
    var metrics = {};
    (0, _keys2.default)(_index4.default).map(function (key) {
      metrics[key] = new _index4.default[key](options);
    });
    return metrics;
  };

  Monitor.prototype.getIntervalMetrics = function getIntervalMetrics() {
    var _this2 = this;

    var metrics = {};
    (0, _keys2.default)(this.intervalMetrics).map(function (key) {
      var metric = _this2.intervalMetrics[key];
      metrics[metric.getMetricsKey()] = metric.getMetricsValue();
    });
    return metrics;
  };

  Monitor.prototype.middleware = function middleware() {
    var _intervalMetrics = this.intervalMetrics;
    var RequestCountMetrics = _intervalMetrics.RequestCountMetrics;
    var ErrorCountMetrics = _intervalMetrics.ErrorCountMetrics;

    return function (req, res, next) {
      RequestCountMetrics.mark();
      if (res.statusCode >= 400) {
        ErrorCountMetrics.mark();
      }
      next();
    };
  };

  return Monitor;
}();

exports.default = Monitor;
//# sourceMappingURL=Monitor.js.map